==> dl.php?src=linea21_1_8.zip: linea21/templates/public/2015/header.php <==
<?php
/**
 * @package linea21\core\public
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
<head>
<base href="<?php echo CURRENT_APP_URL; ?>" />
<meta charset="<?php echo CHARSET; ?>" />
<!--[if IE]><meta http-equiv="X-UA-Compatible" content="IE=edge"><![endif]-->
<meta name="robots" content="index, follow" />
<meta name="description" content="" />
<meta name="viewport" content="width=device-width, initial-scale=1.0">
		<!--[if lt IE 9]>
		<script src="//html5shiv.googlecode.com/svn/trunk/html5.js"></script>
		<![endif]-->
<link rel="icon" type="image/gif" href="<?php echo THEME_PUBLIC_PATH; ?>images/favicon.gif" />
<link rel="stylesheet" href="<?php echo THEME_PUBLIC_PATH; ?>css/knacss.css" media="all">
<link rel="stylesheet" href="<?php echo THEME_PUBLIC_PATH; ?>css/style.css" media="all" />
<link rel="stylesheet" href="<?php echo THEME_PUBLIC_PATH; ?>css/layout.css" media="screen" />

<script src="../lib/js/jquery.min.js"></script>
<?php if(defined('AJAX_LOGIN') && AJAX_LOGIN == 1) echo '<script src="../lib/js/leanModal.v1.1/jquery.leanModal.min.js"></script>'; ?>
<script src="../lib/js/functions.js"></script>
<!--[if IE 8]>
		<link rel="stylesheet" href="<?php echo THEME_PUBLIC_PATH; ?>css/ie8.css" media="screen" />
<![endif]-->
<link rel="stylesheet" href="<?php echo THEME_PUBLIC_PATH; ?>css/print.css" media="print" />
<link rel="alternate" title="RSS2" href="rss2.php" />
<?php distInclude(THEME_PUBLIC_PATH.'meta_data.php', THEME_PUBLIC_DIST); ?>
<?php
IncludeColorboxJs(array("a[href$='.jpg'],a[href$='.jpeg'],a[href$='.png'],a[href$='.gif'], a[href$='.JPG'],a[href$='.JPEG'],a[href$='.PNG'],a[href$='.GIF']"));
AddDynamicHeader();
?>
<title></title>
<?php if(isset($GLOBALS['debugbar'])) echo $GLOBALS['debugbarRenderer']->renderHead(); ?>
</head>

==> dl.php?src=linea21_2_0_0.zip: linea21/templates/public/2015/header.php <==
<?php
/**
 * @package linea21\core\public
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
<head>
<base href="<?php echo CURRENT_APP_URL; ?>" />
<meta charset="<?php echo CHARSET; ?>" />
<!--[if IE]><meta http-equiv="X-UA-Compatible" content="IE=edge"><![endif]-->
<meta name="robots" content="index, follow" />
<meta name="description" content="" />
<meta name="viewport" content="width=device-width, initial-scale=1.0">
		<!--[if lt IE 9]>
		<script src="//html5shiv.googlecode.com/svn/trunk/html5.js"></script>
		<![endif]-->
<link rel="icon" type="image/gif" href="<?php echo THEME_PUBLIC_PATH; ?>images/favicon.gif" />
<link rel="stylesheet" href="<?php echo THEME_PUBLIC_PATH; ?>css/knacss.css" media="all">
<link rel="stylesheet" href="<?php echo THEME_PUBLIC_PATH; ?>css/style.css" media="all" />
<link rel="stylesheet" href="<?php echo THEME_PUBLIC_PATH; ?>css/layout.css" media="screen" />

<script src="../lib/js/jquery-1.11.3.min.js"></script>
<script type="text/javascript" src="../lib/js/jquery-browser.js"></script>
<?php if(defined('AJAX_LOGIN') && AJAX_LOGIN == 1) echo '<script src="../lib/js/leanModal.v1.1/jquery.leanModal.min.js"></script>'; ?>
<script src="../lib/js/functions.js"></script>
<!--[if IE 8]>
		<link rel="stylesheet" href="<?php echo THEME_PUBLIC_PATH; ?>css/ie8.css" media="screen" />
<![endif]-->
<link rel="stylesheet" href="<?php echo THEME_PUBLIC_PATH; ?>css/print.css" media="print" />
<link rel="alternate" title="RSS2" href="rss2.php" />
<?php distInclude(THEME_PUBLIC_PATH.'meta_data.php', THEME_PUBLIC_DIST); ?>
<?php
IncludeColorboxJs(array("a[href$='.jpg'],a[href$='.jpeg'],a[href$='.png'],a[href$='.gif'], a[href$='.JPG'],a[href$='.JPEG'],a[href$='.PNG'],a[href$='.GIF']"));
AddDynamicHeader();
?>
<title></title>
<?php if(isset($GLOBALS['debugbar'])) echo $GLOBALS['debugbarRenderer']->renderHead(); ?>
</head>
